%*%% Uporaba programskega okolja Mathematica za izracun vrednosti funkcij ter
% risanje grafov funkcij*

%Definirajmo funkcijo f(x) = a*e^(b*x)cos(c*x), 
%kjer so vrednosti parametrov a = 2, b = 0,5 ter c = 1,5.

a = 2
b = -0.5
c = 1.5;
% e zakljuimo enabo s podpijem, se izraun ne izpie v ukazni vrstici,
% sicer se izpie. Zato se ob zagonu skripte izpieta vrednosti za a in b ne pa tudi za c.

%Doloimo seznam vrednosti funkcije, ko se spremenljivka x spreminja 
%od vrednosti 5 do 5 s korakom po 0,5.

x=-5:0.5:5;
f=a*exp(b.*x).*cos(c.*x)  % izraun funkcije v tokah niza x


% Izpis tabele
[x;f]'  % zdruim  vektorja (niza) x in f in ju transponiram. 
% Ker izraz ni zakljuen s podpijem, se izpiejo vrednosti
% Preiskusi sam izrise [x,f] ali x' ali [x',f'] ali [x';f']

% Izris tok na grafu
plot(x,f,'*')  % izris tok z zvezdicami 
figure;         % nova slika
plot(x,f,'r*-')  % izris tok z zvezdicami + linija + rdea barva
figure;         % nova slika
plot(x,f,'g--','Linewidth',2)  % izris tok z zvezdicami + linija + rdea barva + debelina rte 2
% V Google vpii Matlab plot in razii druge oblike izrisov - npr. na
% uradni strani Mathworks

% ker je tok premalo za bolj gladek (zvezen) izris, zmanjamo korak med tokami
x=-5:0.1:5; % sedaj je korak 0.1
f=a*exp(b.*x).*cos(c.*x)  % ponoven izraun funkcije za nove toke
figure;         % nova slika
plot(x,f,'k--','Linewidth',2)  % izris tok z zvezdicami + linija + rdea barva

% Opis osi
xlabel('X / m')
ylabel(' f  / T');


%% Nekaj manipulacij z nizi
f(1)  % izpie se prva vrednost v nizu
f(2:10)  % izpie se del niza: od 2 do 10 toke
length(f) % izpie se dolina niza
max(f)      % najveja vrednost v nizu
min(f)      % najmanja vrednost v nizu
mean(f)     % povprena vrednost
find(f==max(f))  % poie indeks pri katerem je vrednost funkcije najveja
x(find(f==max(f)))  % poiemo pri katerem x-u je ta maksimum


%% Numerina Integracija
% z numerino integracijo izraunamo povrino pod krivuljo. Povrina, ki je pod
% absciso (pod f =0) je negativna. 

% izris povrine pod krivuljo s funkcijo area
figure
area(x,f)

% prikaz integracije povrin kot setevanje povrin prikazanih s funkcijo
% bar
figure
bar(x,f,'r')

g=cumsum(f)  % sprotno setevanje f(x)*dx, kjer je dx=0.1
G=sum(f)

figure
plot(x,f,x,g)  % izriemo funkcijo in njen integral

% Malo polepamo in dodamo legendo in mreo
figure
plot(x,f,x,g,'*-','Linewidth',2)  % izriemo funkcijo in njen integral
grid
legend('funkcija f','integral funkcije f')


% Izriimo integral tako, da bo os za funkcijo integrala na desni
figure
plotyy(x,f,x,g)


% Poiimo max vrednost integrala
find(g==max(g))






